@@ -7,6 +7,10 @@
 #' @param .data An object of class \code{waasb} or a two-way table with
 #'   genotypes in the rows and traits in columns. In the last case the row names
 #'   must contain the genotypes names.
+#' @param use_data Define which data to use If \code{.data} is an object of
+#'   class \code{gamem}. Defaults to \code{"blup"} (the BLUPs for genotypes).
+#'   Use \code{"pheno"} to use phenotypic means instead BLUPs for computing the
+#'   index.
 #' @param DI,UI A vector of the same length of \code{.data} to construct the
 #'   desirable (DI) and undesirable (UI) ideotypes. For each element of the
 #'   vector, allowed values are \code{'max'}, \code{'min'}, \code{'mean'}, or a
@@ -31,11 +35,11 @@
 #' * \strong{total_gain} A list with the total gain for variables to be increased or decreased.
 #' @md
 #' @author Tiago Olivoto \email{tiagoolivoto@@gmail.com}
-#' @references Rocha, J.R.A.S.C.R, J.C. Machado, and P.C.S. Carneiro. 2018.
-#'   Multitrait index based on factor analysis and ideotype-design: proposal and
-#'   application on elephant grass breeding for bioenergy. GCB Bioenergy
-#'   10:52-60. doi:
-#'   \href{https://onlinelibrary.wiley.com/doi/full/10.1111/gcbb.12443}{doi:10.1111/gcbb.12443}
+#' @references
+#' Rocha, J.R.A.S.C.R, J.C. Machado, and P.C.S. Carneiro. 2018. Multitrait index
+#' based on factor analysis and ideotype-design: proposal and application on
+#' elephant grass breeding for bioenergy. GCB Bioenergy 10:52-60.
+#' \doi{10.1111/gcbb.12443}
 #'
 #' @export
 #' @examples
@@ -54,11 +58,15 @@
 #'                 UI = c('min, min'))
 #'}
 fai_blup <- function(.data,
+                     use_data = "blup",
                      DI = NULL,
                      UI = NULL,
                      SI = 15,
                      mineval = 1,
                      verbose = TRUE) {
+  if(!use_data %in% c("blup", "pheno")){
+    stop("Argument 'use_data = ", match.call()["use_data"], "'", "invalid. It must be either 'blup' or 'pheno'.")
+  }
   if (!has_class(.data, c("data.frame", "tbl_df", "tbl", "waasb", "gamem"))) {
     stop("The .data must be an object of class 'waasb', 'gamem' or a data.frame/tbl_df.")
   }
@@ -83,7 +91,9 @@ fai_blup <- function(.data,
     stop("The length of DI and UI must be the same length of data.")
   }
   if(has_class(.data, c("gamem", "waasb"))){
-    means <- gmd(.data, "blupg", verbose = FALSE) %>%
+    means <-
+      gmd(.data, ifelse(use_data == "blup", "blupg", "data"), verbose = FALSE) %>%
+      means_by(GEN) %>%
       column_to_rownames("GEN")
   } else {
     if(has_class(.data, c("data.frame", "matrix")) & !has_rownames(.data)){
@@ -249,7 +259,11 @@ fai_blup <- function(.data,
                                  !sense  %in% c("max", "min", "mean") ~ "none"))
       selection.diferential <-
         lapply(selection.diferential, function(x){
-          left_join(x, vars, by = "VAR")
+          left_join(x, vars, by = "VAR") %>%
+            mutate(goal = case_when(
+              sense == "decrease" & SDperc < 0  |  sense == "increase" & SDperc > 0 ~ 100,
+              TRUE ~ 0
+            ))
         })
       total_gain <-
         lapply(selection.diferential, function(x){
@@ -325,11 +339,11 @@ fai_blup <- function(.data,
 #' @param col.nonsel The colour for nonselected genotypes. Defaults to \code{"black"}.
 #' @param ... Other arguments to be passed from ggplot2::theme().
 #' @author Tiago Olivoto \email{tiagoolivoto@@gmail.com}
-#' @references Rocha, J.R.A.S.C.R, J.C. Machado, and P.C.S. Carneiro. 2018.
-#'   Multitrait index based on factor analysis and ideotype-design: proposal and
-#'   application on elephant grass breeding for bioenergy. GCB Bioenergy
-#'   10:52-60. doi:
-#'   \href{https://onlinelibrary.wiley.com/doi/full/10.1111/gcbb.12443}{doi:10.1111/gcbb.12443}.
+#' @references
+#' Rocha, J.R.A.S.C.R, J.C. Machado, and P.C.S. Carneiro. 2018. Multitrait index
+#' based on factor analysis and ideotype-design: proposal and application on
+#' elephant grass breeding for bioenergy. GCB Bioenergy 10:52-60.
+#' \doi{10.1111/gcbb.12443}
 #'
 #' @method plot fai_blup
 #' @export
