@@ -8,10 +8,11 @@
 #' @name get_model_data
 #'
 #' @param x An object created with the functions \code{\link{AMMI_indexes}()},
-#'   \code{\link{anova_ind}()}, \code{\link{anova_joint}()}, \code{\link{can_corr}()}
-#'   \code{\link{ecovalence}()},  \code{\link{Fox}()}, \code{\link{gai}()},
-#'   \code{\link{gamem}()},\code{\link{gafem}()}, \code{\link{ge_means}()},
-#'   \code{\link{ge_reg}()}, \code{\link{gytb}()}, \code{\link{performs_ammi}()},
+#'   \code{\link{anova_ind}()}, \code{\link{anova_joint}()},
+#'   \code{\link{can_corr}()} \code{\link{ecovalence}()},  \code{\link{Fox}()},
+#'   \code{\link{gai}()}, \code{\link{gamem}()},\code{\link{gafem}()},
+#'   \code{\link{ge_acv}}, \code{\link{ge_means}()}, \code{\link{ge_reg}()},
+#'   \code{\link{gytb}()}, \code{\link{performs_ammi}()},
 #'   \code{\link{Resende_indexes}()}, \code{\link{Shukla}()},
 #'   \code{\link{superiority}()}, \code{\link{waas}()} or \code{\link{waasb}()}.
 #' @param what What should be captured from the model. See more in section
@@ -81,6 +82,14 @@
 #' * \code{"Ecov_perc"} Ecovalence in percentage value.
 #' * \code{"rank"} Rank for ecovalence.
 #'
+#'  \strong{Objects of class \code{ge_acv}:}
+#' * \code{"ACV"} The adjusted coefficient of variation (default).
+#' * \code{"ACV_R"} The rank for adjusted coefficient of variation.
+#'
+#'  \strong{Objects of class \code{ge_polar}:}
+#' * \code{"POLAR"} The Power Law Residuals (default).
+#' * \code{"POLAR_R"} The rank for Power Law Residuals.
+#'
 #'  \strong{Objects of class \code{ge_reg}:}
 #' * \code{"deviations"} The deviations from regression.
 #' * \code{"RMSE"} The Root Mean Square Error.
@@ -263,7 +272,8 @@
 #' @seealso \code{\link{AMMI_indexes}}, \code{\link{anova_ind}},
 #'   \code{\link{anova_joint}}, \code{\link{ecovalence}},  \code{\link{Fox}},
 #'   \code{\link{gai}}, \code{\link{gamem}}, \code{\link{gafem}},
-#'   \code{\link{ge_means}}, \code{\link{ge_reg}}, \code{\link{performs_ammi}},
+#'   \code{\link{ge_acv}}, \code{\link{ge_polar}} \code{\link{ge_means}},
+#'   \code{\link{ge_reg}}, \code{\link{performs_ammi}},
 #'   \code{\link{Resende_indexes}}, \code{\link{Shukla}},
 #'   \code{\link{superiority}}, \code{\link{waas}}, \code{\link{waasb}}
 #' @examples
@@ -351,7 +361,8 @@ get_model_data <- function(x,
                       "AMMI_indexes", "ecovalence", "ge_reg", "Fox", "Shukla",
                       "superiority", "ge_effects", "gai", "Huehn", "Thennarasu",
                       "ge_stats", "Annicchiarico", "Schmildt", "ge_means", "anova_joint",
-                      "gafem", "anova_ind", "gge", "can_cor", "can_cor_group", "gytb"))) {
+                      "gafem", "anova_ind", "gge", "can_cor", "can_cor_group", "gytb",
+                      "ge_acv", "ge_polar"))) {
     stop("Invalid class in object ", call_f[["x"]], ". See ?get_model_data for more information.")
   }
   if (!is.null(what) && substr(what, 1, 2) == "PC") {
@@ -393,6 +404,8 @@ get_model_data <- function(x,
   check22 <- c("scores", "exp_var")
   check23 <- c("coefs", "loads", "crossloads", "canonical")
   check24 <- c("gyt", "stand_gyt", "si")
+  check25 <- c("ACV", "ACV_R")
+  check26 <- c("POLAR", "POLAR_R")
   if (!is.null(what) && what %in% check3 && !has_class(x, c("waasb", "gamem", "gafem", "anova_joint"))) {
     stop("Invalid argument 'what'. It can only be used with an oject of class 'waasb' or 'gamem', 'gafem, or 'anova_joint'. Please, check and fix.")
   }
@@ -400,6 +413,35 @@ get_model_data <- function(x,
     stop("Argument 'type' invalid. It must be either 'GEN' or 'ENV'.")
   }
 
+  if (has_class(x,  "ge_polar")) {
+    if (is.null(what)){
+      what <- "POLAR"
+    }
+    if (!what %in% check26) {
+      stop("Invalid value in 'what' for object of class 'ge_acv'. Allowed are ", paste(check26, collapse = ", "), call. = FALSE)
+    }
+    bind <- sapply(x, function(x) {
+      x[[what]]
+    }) %>%
+      as_tibble() %>%
+      mutate(gen = x[[1]][["GEN"]]) %>%
+      column_to_first(gen)
+  }
+
+  if (has_class(x,  "ge_acv")) {
+    if (is.null(what)){
+      what <- "ACV"
+    }
+    if (!what %in% check25) {
+      stop("Invalid value in 'what' for object of class 'ge_acv'. Allowed are ", paste(check25, collapse = ", "), call. = FALSE)
+    }
+    bind <- sapply(x, function(x) {
+      x[[what]]
+    }) %>%
+      as_tibble() %>%
+      mutate(gen = x[[1]][["GEN"]]) %>%
+      column_to_first(gen)
+  }
 
   if(has_class(x,  "gge") & length(class(x)) == 1){
     if (is.null(what)){
