@@ -32,9 +32,11 @@
 #' * \strong{contri.fac} The relative contribution of each factor on the MTSI value.
 #' The lower the contribution of a factor, the close of the ideotype the variables in such
 #' factor are.
-#' * \strong{sel.dif} The selection differential for the WAASBY or WAASB index.
+#' * \strong{sel.dif} The selection differential for the WAASBY index.
 #' * \strong{mean.sd} The mean for the differential selection.
 #' * \strong{sel.dif.var} The selection differential for the variables.
+#' * \strong{total.sel.dif} The total selection differential.
+#' * \strong{sel.dif.waasb} The selection differential for WAASB index.
 #' * \strong{Selected} The selected genotypes.
 #' @md
 #' @author Tiago Olivoto \email{tiagoolivoto@@gmail.com}
@@ -192,7 +194,7 @@ mtsi <- function(.data,
     sel.dif.mean <-
       tibble(VAR = names(pos.var.factor[, 2]),
              Factor = paste("FA", as.numeric(pos.var.factor[, 2])),
-             xo = colMeans(observed),
+             Xo = colMeans(observed),
              Xs = colMeans(observed[names(MTSI)[1:ngs], ]),
              SD = Xs - colMeans(observed),
              SDperc = (Xs - colMeans(observed)) / colMeans(observed) * 100) %>%
@@ -208,9 +210,36 @@ mtsi <- function(.data,
                sense == "decrease" & SDperc < 0  |  sense == "increase" & SDperc > 0 ~ 100,
                TRUE ~ 0
              ))
+    if (class(.data) == "waasb") {
+      h2 <- gmd(.data, "h2", verbose = FALSE)
+      sel.dif.mean <-
+        left_join(sel.dif.mean, h2, by = "VAR") %>%
+        add_cols(SG = SD * h2,
+                 SGperc = SG / Xo * 100,
+                 .after = "SDperc") %>%
+        reorder_cols(h2, .after  = "SDperc")
+    }
+    tota_gain <-
+      sum_by(sel.dif.mean, sense) %>%
+      select_cols(sense, one_of(c("SD", "SDperc", "SG", "SGperc")))
+
+
+    selected <- names(MTSI)[1:ngs]
+    what <- ifelse(has_class(.data, "WAASB"), "WAAS", "WAASB")
+    waasb_index <- gmd(.data, what, verbose = FALSE)
+    waasb_selected <- colMeans(subset(waasb_index, gen %in% selected) %>% select_numeric_cols())
+    sel.dif.waasb <-
+      tibble(
+        TRAIT = names(waasb_selected),
+        Xo = colMeans(waasb_index %>% select_numeric_cols()),
+        Xs = waasb_selected,
+        SD = Xs - Xo,
+        SDperc = (Xs - Xo) / Xo * 100)
   }
   if (is.null(ngs)) {
     sel.dif <- NULL
+    sel.dif.waasb <- NULL
+    sel.dif.mean <- NULL
   }
   if (verbose) {
     cat("\n-------------------------------------------------------------------------------\n")
@@ -239,7 +268,7 @@ mtsi <- function(.data,
       cat("------------------------------------------------------------------------------\n")
       cat("Selected genotypes\n")
       cat("-------------------------------------------------------------------------------\n")
-      cat(names(MTSI)[1:ngs])
+      cat(selected)
       cat("\n-------------------------------------------------------------------------------\n")
     }
   }
@@ -261,6 +290,8 @@ mtsi <- function(.data,
                         sel.dif = sel.dif,
                         mean.sd = mean_sd_ind,
                         sel.dif.var = sel.dif.mean,
+                        total.sel.dif = tota_gain,
+                        sel.dif.waasb = sel.dif.waasb,
                         Selected = names(MTSI)[1:ngs]),
                    class = "mtsi"))
 }
@@ -271,8 +302,6 @@ mtsi <- function(.data,
 
 
 
-
-
 #' Plot the multi-trait stability index
 #'
 #' Makes a radar plot showing the multitrait stability index proposed by Olivoto
