@@ -1,18 +1,16 @@
 #' @import ggplot2
 #' @import stats
-#' @importFrom dplyr  select  everything  mutate  group_by  group_by_if
-#'   group_keys group_split  left_join  sample_n  anti_join pull select_if
-#'   arrange slice contains top_n summarise ungroup rename is_grouped_df desc n
-#'   funs
+#' @import mathjaxr
+#' @importFrom dplyr  select  everything  mutate  group_by group_keys
+#'   group_split  left_join  sample_n  anti_join pull select_if arrange slice
+#'   contains top_n summarise ungroup rename is_grouped_df desc n funs
 #' @importFrom tibble rownames_to_column column_to_rownames tibble as_tibble
 #' @importFrom grid grobTree textGrob
 #' @importFrom ggrepel  geom_text_repel geom_label_repel
 #' @importFrom magrittr  %>% %<>%
 #' @importFrom GGally  ggally_text  eval_data_col  ggpairs
-#' @importFrom ade4  mantel.randtest
 #' @importFrom lme4  ranef  VarCorr  fortify.merMod
 #' @importFrom lmerTest  ranova  lmer
-#' @importFrom FWDselect  selection
 #' @importFrom grDevices  colorRampPalette  dev.off  pdf
 #'             chull  tiff  boxplot.stats
 #' @importFrom methods  is  as
@@ -155,7 +153,7 @@ NULL
 NULL
 
 .onAttach <- function(libname, pkgname) {
-  vers <-  "v1.8.1"
+  vers <-  "v1.9.0"
   packageStartupMessage("[]========================================================[]")
   packageStartupMessage("[] Multi-Environment Trial Analysis (metan) ", vers, "        []")
   packageStartupMessage("[] Author: Tiago Olivoto                                  []")
@@ -190,5 +188,5 @@ if (getRversion() >= "2.15.1") {
       "intercept", "lower", "upper", "pred_ols", "res_ammi", "res_ols", "pattern",
       "replacement", "comparison", "group1", "group2", "p.adj", "term", "rel_freq",
       "variable", "Model", "level", "RESIDUAL", "MGIDI", "sd.amo", "SD", "SG", "data.x",
-      "data.y", "sense", "win", "where", "test", "FG", "SI"))
+      "data.y", "sense", "win", "where", "test", "FG", "SI", "ACV"))
   }
